@@ -17,7 +17,6 @@ pub struct Client {
 }
 
 impl Client {
-
     pub fn new(api_key: Option<String>, secret_key: Option<String>, host: String) -> Self {
         Client {
             api_key: api_key.unwrap_or_else(|| "".into()),
@@ -30,7 +29,9 @@ impl Client {
         }
     }
 
-    pub fn get_signed<T: DeserializeOwned>(&self, endpoint: API, request: Option<String>) -> Result<T> {
+    pub fn get_signed<T: DeserializeOwned>(
+        &self, endpoint: API, request: Option<String>,
+    ) -> Result<T> {
         let url = self.sign_request(endpoint, request);
         let client = &self.inner_client;
         let response = client
@@ -52,7 +53,9 @@ impl Client {
         self.handler(response)
     }
 
-    pub fn delete_signed<T: DeserializeOwned>(&self, endpoint: API, request: Option<String>) -> Result<T> {
+    pub fn delete_signed<T: DeserializeOwned>(
+        &self, endpoint: API, request: Option<String>,
+    ) -> Result<T> {
         let url = self.sign_request(endpoint, request);
         let client = &self.inner_client;
         let response = client
@@ -121,14 +124,16 @@ impl Client {
     fn sign_request(&self, endpoint: API, request: Option<String>) -> String {
         match request {
             Some(request) => {
-                let mut signed_key = Hmac::<Sha256>::new_from_slice(self.secret_key.as_bytes()).unwrap();
+                let mut signed_key =
+                    Hmac::<Sha256>::new_from_slice(self.secret_key.as_bytes()).unwrap();
                 signed_key.update(request.as_bytes());
                 let signature = hex_encode(signed_key.finalize().into_bytes());
                 let request_body: String = format!("{}&signature={}", request, signature);
                 format!("{}{}?{}", self.host, String::from(endpoint), request_body)
-            },
+            }
             None => {
-                let signed_key = Hmac::<Sha256>::new_from_slice(self.secret_key.as_bytes()).unwrap();
+                let signed_key =
+                    Hmac::<Sha256>::new_from_slice(self.secret_key.as_bytes()).unwrap();
                 let signature = hex_encode(signed_key.finalize().into_bytes());
                 let request_body: String = format!("&signature={}", signature);
                 format!("{}{}?{}", self.host, String::from(endpoint), request_body)
@@ -156,9 +161,7 @@ impl Client {
 
     fn handler<T: DeserializeOwned>(&self, response: Response) -> Result<T> {
         match response.status() {
-            StatusCode::OK => {
-                Ok(response.json::<T>()?)
-            }
+            StatusCode::OK => Ok(response.json::<T>()?),
             StatusCode::INTERNAL_SERVER_ERROR => {
                 bail!("Internal Server Error");
             }
