@@ -28,6 +28,7 @@ use std::collections::BTreeMap;
 use serde_json::Value;
 use crate::api::API;
 use crate::api::Futures;
+use std::convert::TryInto;
 
 // TODO
 // Make enums for Strings
@@ -74,7 +75,8 @@ impl FuturesMarket {
         let mut parameters: BTreeMap<String, String> = BTreeMap::new();
         parameters.insert("symbol".into(), symbol.into());
         let request = build_request(parameters);
-        self.client.get(API::Futures(Futures::Trades), Some(request))
+        self.client
+            .get(API::Futures(Futures::Trades), Some(request))
     }
 
     // TODO This may be incomplete, as it hasn't been tested
@@ -100,7 +102,8 @@ impl FuturesMarket {
 
         let request = build_signed_request(parameters, self.recv_window)?;
 
-        self.client.get_signed(API::Futures(Futures::HistoricalTrades), Some(request))
+        self.client
+            .get_signed(API::Futures(Futures::HistoricalTrades), Some(request))
     }
 
     pub fn get_agg_trades<S1, S2, S3, S4, S5>(
@@ -133,7 +136,8 @@ impl FuturesMarket {
 
         let request = build_request(parameters);
 
-        self.client.get(API::Futures(Futures::AggTrades), Some(request))
+        self.client
+            .get(API::Futures(Futures::AggTrades), Some(request))
     }
 
     // Returns up to 'limit' klines for given symbol and interval ("1m", "5m", ...)
@@ -172,21 +176,10 @@ impl FuturesMarket {
 
         let klines = KlineSummaries::AllKlineSummaries(
             data.iter()
-                .map(|row| KlineSummary {
-                    open_time: to_i64(&row[0]),
-                    open: to_f64(&row[1]),
-                    high: to_f64(&row[2]),
-                    low: to_f64(&row[3]),
-                    close: to_f64(&row[4]),
-                    volume: to_f64(&row[5]),
-                    close_time: to_i64(&row[6]),
-                    quote_asset_volume: to_f64(&row[7]),
-                    number_of_trades: to_i64(&row[8]),
-                    taker_buy_base_asset_volume: to_f64(&row[9]),
-                    taker_buy_quote_asset_volume: to_f64(&row[10]),
-                })
-                .collect(),
+                .map(|row| row.try_into())
+                .collect::<Result<Vec<KlineSummary>>>()?,
         );
+
         Ok(klines)
     }
 
@@ -200,12 +193,12 @@ impl FuturesMarket {
         parameters.insert("symbol".into(), symbol.into());
         let request = build_request(parameters);
 
-        self.client.get(API::Futures(Futures::Ticker24hr), Some(request))
+        self.client
+            .get(API::Futures(Futures::Ticker24hr), Some(request))
     }
 
     // 24hr ticker price change statistics for all symbols
-    pub fn get_all_24h_price_stats(&self) -> Result<Vec<PriceStats>>
-    {
+    pub fn get_all_24h_price_stats(&self) -> Result<Vec<PriceStats>> {
         self.client.get(API::Futures(Futures::Ticker24hr), None)
     }
 
@@ -219,12 +212,12 @@ impl FuturesMarket {
         parameters.insert("symbol".into(), symbol.into());
         let request = build_request(parameters);
 
-        self.client.get(API::Futures(Futures::TickerPrice), Some(request))
+        self.client
+            .get(API::Futures(Futures::TickerPrice), Some(request))
     }
-    
+
     // Latest price for all symbols.
-    pub fn get_all_prices(&self) -> Result<crate::model::Prices>
-    {
+    pub fn get_all_prices(&self) -> Result<crate::model::Prices> {
         self.client.get(API::Futures(Futures::TickerPrice), None)
     }
 
@@ -242,7 +235,8 @@ impl FuturesMarket {
         let mut parameters: BTreeMap<String, String> = BTreeMap::new();
         parameters.insert("symbol".into(), symbol.into());
         let request = build_request(parameters);
-        self.client.get(API::Futures(Futures::BookTicker), Some(request))
+        self.client
+            .get(API::Futures(Futures::BookTicker), Some(request))
     }
 
     pub fn get_mark_prices(&self) -> Result<MarkPrices> {
@@ -260,6 +254,7 @@ impl FuturesMarket {
         let mut parameters: BTreeMap<String, String> = BTreeMap::new();
         parameters.insert("symbol".into(), symbol.into());
         let request = build_request(parameters);
-        self.client.get(API::Futures(Futures::OpenInterest), Some(request))
+        self.client
+            .get(API::Futures(Futures::OpenInterest), Some(request))
     }
 }
